aboutsummaryrefslogtreecommitdiffstats
path: root/railties/lib/rails/application.rb
diff options
context:
space:
mode:
Diffstat (limited to 'railties/lib/rails/application.rb')
-rw-r--r--railties/lib/rails/application.rb16
1 files changed, 9 insertions, 7 deletions
diff --git a/railties/lib/rails/application.rb b/railties/lib/rails/application.rb
index 2648476d6d..acbfd7078b 100644
--- a/railties/lib/rails/application.rb
+++ b/railties/lib/rails/application.rb
@@ -115,19 +115,21 @@ module Rails
# A plugin may override this if they desire to provide a more
# exquisite route reloading.
# :api: plugin
- def routes_reloader_hook
- app = self
- lambda { app.routes_reloader.execute_if_updated }
+ def set_routes_reloader_hook
+ reloader = routes_reloader
+ hook = lambda { reloader.execute_if_updated }
+ hook.call
+ ActionDispatch::Reloader.to_prepare(&hook)
end
# An app reloader hook that is used to setup to_cleanup callbacks.
# A plugin may override this if they desire to provide a more exquisite app reloading.
# :api: plugin
- def app_reloader_hook
- lambda {
+ def set_dependencies_hook
+ ActionDispatch::Reloader.to_cleanup do
ActiveSupport::DescendantsTracker.clear
ActiveSupport::Dependencies.clear
- }
+ end
end
# Initialize the application passing the given group. By default, the
@@ -115,19 +115,21 @@ module Rails
end
- # An app reloader hook that is used to setup to_cleanup callbacks.
+ # An app dependencies hook that is used to setup to_cleanup callbacks.
# A plugin may override this if they desire to provide a more exquisite app reloading.
# :api: plugin